summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2005-03-26 05:29:23 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2005-03-26 05:29:23 +0000
commitfcc83f4256ee2e1b9c54d75486988a90438d6a72 (patch)
treec52e0c63d6d3205df7010f2952b8586cd5159cd6
parent199365109ba2766d2160673b0eb0cdb88ba57086 (diff)
downloadATCD-fcc83f4256ee2e1b9c54d75486988a90438d6a72.tar.gz
*** empty log message ***
-rw-r--r--TAO/TAO_IDL/be/be_codegen.cpp8
-rw-r--r--TAO/tao/DynamicA.cpp132
-rw-r--r--TAO/tao/GIOPA.cpp3
-rw-r--r--TAO/tao/TypeCode_Case.cpp18
-rw-r--r--TAO/tao/TypeCode_Case.inl2
-rw-r--r--TAO/tao/TypeCode_Non_Default_Case.cpp6
-rw-r--r--TAO/tao/Union_TypeCode.cpp18
-rw-r--r--TAO/tao/Union_TypeCode.inl6
8 files changed, 118 insertions, 75 deletions
diff --git a/TAO/TAO_IDL/be/be_codegen.cpp b/TAO/TAO_IDL/be/be_codegen.cpp
index ca3905116c9..ceee6105c8b 100644
--- a/TAO/TAO_IDL/be/be_codegen.cpp
+++ b/TAO/TAO_IDL/be/be_codegen.cpp
@@ -1993,8 +1993,6 @@ TAO_CodeGen::gen_typecode_includes (TAO_OutStream * stream)
// this->gen_standard_include (stream,
// "tao/TypeCode.h");
-
-
this->gen_standard_include (stream,
"tao/Null_RefCount_Policy.h");
@@ -2007,7 +2005,7 @@ TAO_CodeGen::gen_typecode_includes (TAO_OutStream * stream)
"tao/Alias_TypeCode.h");
this->gen_cond_file_include (idl_global->enum_seen_,
- "tao/TypeCode_Non_Default_Case.h",
+ "tao/TypeCode_Enumerator.h",
stream);
this->gen_cond_file_include (idl_global->enum_seen_,
@@ -2039,6 +2037,10 @@ TAO_CodeGen::gen_typecode_includes (TAO_OutStream * stream)
stream);
this->gen_cond_file_include (idl_global->union_seen_,
+ "tao/TypeCode_Non_Default_Case.h",
+ stream);
+
+ this->gen_cond_file_include (idl_global->union_seen_,
"tao/Union_TypeCode.h",
stream);
diff --git a/TAO/tao/DynamicA.cpp b/TAO/tao/DynamicA.cpp
index d8c0777235a..3f4748f3b77 100644
--- a/TAO/tao/DynamicA.cpp
+++ b/TAO/tao/DynamicA.cpp
@@ -36,25 +36,35 @@
#include "tao/Any_Dual_Impl_T.h"
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/typecode_defn.cpp:744
+// be/be_visitor_typecode/typecode_defn.cpp:743
+
+namespace TAO
+{
+ namespace TypeCode
+ {
+ TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
+ Dynamic_ParameterList_0 (
+ CORBA::tk_sequence,
+ &Dynamic::_tc_Parameter,
+ 0U);
+
+ ::CORBA::TypeCode_ptr const tc_Dynamic_ParameterList_0 =
+ &Dynamic_ParameterList_0;
+
+ }
+}
-static TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
- _tao_tc_Dynamic_ParameterList_0 (
- CORBA::tk_sequence,
- &Dynamic::_tc_Parameter,
- 0U);
-
static TAO::TypeCode::Alias<char const *,
TAO::Null_RefCount_Policy>
_tao_tc_Dynamic_ParameterList (
"IDL:omg.org/Dynamic/ParameterList:1.0",
"ParameterList",
- &::_tao_tc_Dynamic_ParameterList_0);
+ &TAO::TypeCode::tc_Dynamic_ParameterList_0);
namespace Dynamic
{
@@ -65,30 +75,40 @@ namespace Dynamic
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/typecode_defn.cpp:744
+// be/be_visitor_typecode/typecode_defn.cpp:743
+
+namespace TAO
+{
+ namespace TypeCode
+ {
+ TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
+ CORBA_sequence_0 (
+ CORBA::tk_sequence,
+ &CORBA::_tc_string,
+ 0U);
+
+ ::CORBA::TypeCode_ptr const tc_CORBA_sequence_0 =
+ &CORBA_sequence_0;
+
+ }
+}
-static TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
- _tao_tc_CORBA_sequence_0 (
- CORBA::tk_sequence,
- &::_tao_tc_CORBA::_tc_string,
- 0U);
-
static TAO::TypeCode::Alias<char const *,
TAO::Null_RefCount_Policy>
_tao_tc_CORBA_StringSeq (
"IDL:omg.org/CORBA/StringSeq:1.0",
"StringSeq",
- &::_tao_tc_CORBA_sequence_0);
+ &TAO::TypeCode::tc_CORBA_sequence_0);
namespace CORBA
{
@@ -112,25 +132,35 @@ namespace Dynamic
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/typecode_defn.cpp:744
+// be/be_visitor_typecode/typecode_defn.cpp:743
+
+namespace TAO
+{
+ namespace TypeCode
+ {
+ TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
+ Dynamic_ExceptionList_0 (
+ CORBA::tk_sequence,
+ &CORBA::_tc_TypeCode,
+ 0U);
+
+ ::CORBA::TypeCode_ptr const tc_Dynamic_ExceptionList_0 =
+ &Dynamic_ExceptionList_0;
+
+ }
+}
-static TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
- _tao_tc_Dynamic_ExceptionList_0 (
- CORBA::tk_sequence,
- &CORBA::_tc_TypeCode,
- 0U);
-
static TAO::TypeCode::Alias<char const *,
TAO::Null_RefCount_Policy>
_tao_tc_Dynamic_ExceptionList (
"IDL:omg.org/Dynamic/ExceptionList:1.0",
"ExceptionList",
- &::_tao_tc_Dynamic_ExceptionList_0);
+ &TAO::TypeCode::tc_Dynamic_ExceptionList_0);
namespace Dynamic
{
@@ -141,30 +171,40 @@ namespace Dynamic
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/alias_typecode.cpp:31
+// be/be_visitor_typecode/alias_typecode.cpp:31
// TAO_IDL - Generated from
-// be\be_visitor_typecode/typecode_defn.cpp:744
+// be/be_visitor_typecode/typecode_defn.cpp:743
+
+namespace TAO
+{
+ namespace TypeCode
+ {
+ TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
+ CORBA_sequence_0 (
+ CORBA::tk_sequence,
+ &CORBA::_tc_string,
+ 0U);
+
+ ::CORBA::TypeCode_ptr const tc_CORBA_sequence_0 =
+ &CORBA_sequence_0;
+
+ }
+}
-static TAO::TypeCode::Sequence<TAO::Null_RefCount_Policy>
- _tao_tc_CORBA_sequence_0 (
- CORBA::tk_sequence,
- &::_tao_tc_CORBA::_tc_string,
- 0U);
-
static TAO::TypeCode::Alias<char const *,
TAO::Null_RefCount_Policy>
_tao_tc_CORBA_StringSeq (
"IDL:omg.org/CORBA/StringSeq:1.0",
"StringSeq",
- &::_tao_tc_CORBA_sequence_0);
+ &TAO::TypeCode::tc_CORBA_sequence_0);
namespace CORBA
{
@@ -188,7 +228,7 @@ namespace Dynamic
// TAO_IDL - Generated from
-// be\be_visitor_sequence/any_op_cs.cpp:54
+// be/be_visitor_sequence/any_op_cs.cpp:54
// Copying insertion.
void operator<<= (
@@ -199,7 +239,7 @@ void operator<<= (
TAO::Any_Dual_Impl_T<Dynamic::ParameterList>::insert_copy (
_tao_any,
Dynamic::ParameterList::_tao_any_destructor,
- Dynamic_ParameterList_0,
+ TAO::TypeCode::tc_Dynamic_ParameterList_0,
_tao_elem
);
}
@@ -213,7 +253,7 @@ void operator<<= (
TAO::Any_Dual_Impl_T<Dynamic::ParameterList>::insert (
_tao_any,
Dynamic::ParameterList::_tao_any_destructor,
- Dynamic_ParameterList_0,
+ TAO::TypeCode::tc_Dynamic_ParameterList_0,
_tao_elem
);
}
@@ -240,13 +280,13 @@ CORBA::Boolean operator>>= (
TAO::Any_Dual_Impl_T<Dynamic::ParameterList>::extract (
_tao_any,
Dynamic::ParameterList::_tao_any_destructor,
- Dynamic_ParameterList_0,
+ TAO::TypeCode::tc_Dynamic_ParameterList_0,
_tao_elem
);
}
// TAO_IDL - Generated from
-// be\be_visitor_sequence/any_op_cs.cpp:54
+// be/be_visitor_sequence/any_op_cs.cpp:54
// Copying insertion.
void operator<<= (
@@ -257,7 +297,7 @@ void operator<<= (
TAO::Any_Dual_Impl_T<Dynamic::ExceptionList>::insert_copy (
_tao_any,
Dynamic::ExceptionList::_tao_any_destructor,
- Dynamic_ExceptionList_0,
+ TAO::TypeCode::tc_Dynamic_ExceptionList_0,
_tao_elem
);
}
@@ -271,7 +311,7 @@ void operator<<= (
TAO::Any_Dual_Impl_T<Dynamic::ExceptionList>::insert (
_tao_any,
Dynamic::ExceptionList::_tao_any_destructor,
- Dynamic_ExceptionList_0,
+ TAO::TypeCode::tc_Dynamic_ExceptionList_0,
_tao_elem
);
}
@@ -298,7 +338,7 @@ CORBA::Boolean operator>>= (
TAO::Any_Dual_Impl_T<Dynamic::ExceptionList>::extract (
_tao_any,
Dynamic::ExceptionList::_tao_any_destructor,
- Dynamic_ExceptionList_0,
+ TAO::TypeCode::tc_Dynamic_ExceptionList_0,
_tao_elem
);
}
diff --git a/TAO/tao/GIOPA.cpp b/TAO/tao/GIOPA.cpp
index 84fffd77082..40af8a34db1 100644
--- a/TAO/tao/GIOPA.cpp
+++ b/TAO/tao/GIOPA.cpp
@@ -31,6 +31,7 @@
#include "tao/Alias_TypeCode.h"
#include "tao/String_TypeCode.h"
#include "tao/Struct_TypeCode.h"
+#include "tao/TypeCode_Non_Default_Case.h"
#include "tao/Union_TypeCode.h"
#include "tao/CDR.h"
#include "tao/Any.h"
@@ -128,7 +129,7 @@ static TAO::TypeCode::Union<char const *,
&CORBA::_tc_short,
_tao_cases_GIOP_TargetAddress,
3,-1,
- 0, 0);
+ 0, static_cast<CORBA::TypeCode_ptr const *>(0));
namespace GIOP
{
diff --git a/TAO/tao/TypeCode_Case.inl b/TAO/tao/TypeCode_Case.inl
index b97d1e718be..3dbc08258f5 100644
--- a/TAO/tao/TypeCode_Case.inl
+++ b/TAO/tao/TypeCode_Case.inl
@@ -35,7 +35,7 @@ TAO::TypeCode::Case<STRING_TYPE>::marshal (
TAO_OutputCDR & cdr) const
{
return
- this->marshal_label ()
+ this->marshal_label (cdr)
&& (cdr << this->name ())
&& (cdr << this->type ());
}
diff --git a/TAO/tao/TypeCode_Non_Default_Case.cpp b/TAO/tao/TypeCode_Non_Default_Case.cpp
index 8b04c406048..d6cf911a30a 100644
--- a/TAO/tao/TypeCode_Non_Default_Case.cpp
+++ b/TAO/tao/TypeCode_Non_Default_Case.cpp
@@ -24,7 +24,7 @@ namespace TAO
return v;
}
- inline static T any_to (T & v)
+ inline static T & any_to (T & v)
{
return v;
}
@@ -108,8 +108,8 @@ TAO::TypeCode::Non_Default_Case<DISCRIMINATOR_TYPE,
// boolean, or (4) an enumeration.
DISCRIMINATOR_TYPE tc_label;
- if (any.in ()
- >>= TAO::TypeCode::Case_Traits<DISCRIMINATOR_TYPE>::any_to (tc_label)
+ if ((any.in ()
+ >>= TAO::TypeCode::Case_Traits<DISCRIMINATOR_TYPE>::any_to (tc_label))
&& this->label_ == tc_label)
{
return true;
diff --git a/TAO/tao/Union_TypeCode.cpp b/TAO/tao/Union_TypeCode.cpp
index d8e546af3e0..9a128b2e36c 100644
--- a/TAO/tao/Union_TypeCode.cpp
+++ b/TAO/tao/Union_TypeCode.cpp
@@ -102,8 +102,8 @@ TAO::TypeCode::Union<StringType,
ACE_CHECK_RETURN (0);
CORBA::Boolean const equal_discriminators =
- (*this->discriminator_type_)->equal (tc_discriminator.in ()
- ACE_ENV_ARG_PARAMETER);
+ (*this->discriminant_type_)->equal (tc_discriminator.in ()
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (0);
if (!equal_discriminators)
@@ -183,8 +183,8 @@ TAO::TypeCode::Union<StringType,
ACE_CHECK_RETURN (0);
CORBA::Boolean const equiv_discriminators =
- (*this->discriminator_type_)->equivalent (tc_discriminator.in ()
- ACE_ENV_ARG_PARAMETER);
+ (*this->discriminant_type_)->equivalent (tc_discriminator.in ()
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (0);
if (!equiv_discriminators)
@@ -227,6 +227,7 @@ TAO::TypeCode::Union<StringType,
RefCountPolicy>::get_compact_typecode_i (
ACE_ENV_SINGLE_ARG_DECL) const
{
+#if 0
case_type * tc_cases = 0;
ACE_Auto_Array_Ptr<Case<CORBA::String_var> > safe_cases;
@@ -268,10 +269,6 @@ TAO::TypeCode::Union<StringType,
CORBA::TypeCode::_nil ());
}
- CORBA::TCKind const this_kind =
- this->kind_i (ACE_ENV_SINGLE_ARG_PARAMETER);
- ACE_CHECK_RETURN (CORBA::TypeCode::_nil ());
-
CORBA::TypeCode_var tc =
adapter->_tao_create_union_tc (this->base_attributes_.id (),
"", /* empty name */
@@ -287,6 +284,9 @@ TAO::TypeCode::Union<StringType,
(void) safe_cases.release ();
return tc._retn ();
+#else
+ ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), CORBA::TypeCode::_nil ());
+#endif /* 0 */
}
template <typename StringType, class CaseArrayType, class RefCountPolicy>
@@ -371,7 +371,7 @@ TAO::TypeCode::Union<StringType,
RefCountPolicy>::discriminator_type_i (
ACE_ENV_SINGLE_ARG_DECL) const
{
- return CORBA::TypeCode::_duplicate (*this->discriminator_type_);
+ return CORBA::TypeCode::_duplicate (*this->discriminant_type_);
}
template <typename StringType, class CaseArrayType, class RefCountPolicy>
diff --git a/TAO/tao/Union_TypeCode.inl b/TAO/tao/Union_TypeCode.inl
index 3f431d53a5f..9c9ccdfee8f 100644
--- a/TAO/tao/Union_TypeCode.inl
+++ b/TAO/tao/Union_TypeCode.inl
@@ -36,9 +36,9 @@ TAO::TypeCode::Union<StringType,
}
template <typename StringType, typename CaseArrayType, class RefCountPolicy>
-ACE_INLINE TAO::TypeCode::Union<StringType,
- CaseArrayType,
- RefCountPolicy>::case_type const &
+ACE_INLINE typename TAO::TypeCode::Union<StringType,
+ CaseArrayType,
+ RefCountPolicy>::case_type const &
TAO::TypeCode::Union<StringType,
CaseArrayType,
RefCountPolicy>::the_case (CORBA::ULong index) const
diff --git a/TAO/tao/TypeCode_Case.cpp b/TAO/tao/TypeCode_Case.cpp
index b257c910aa3..3afc5be5a47 100644
--- a/TAO/tao/TypeCode_Case.cpp
+++ b/TAO/tao/TypeCode_Case.cpp
@@ -47,10 +47,10 @@ TAO::TypeCode::Case<STRING_TYPE>::equal (CORBA::ULong index,
if (!equal_members)
return 0;
- // Check case labels.
- return this->equal_labels (index,
- tc
- ACE_ENV_ARG_PARAMETER);
+ // Check case label.
+ return this->equal_label (index,
+ tc
+ ACE_ENV_ARG_PARAMETER);
}
template <typename STRING_TYPE>
@@ -76,11 +76,11 @@ TAO::TypeCode::Case<STRING_TYPE>::equivalent (CORBA::ULong index,
if (!equivalent_members)
return 0;
- // Check case labels.
- // The labels must be equal when determining equivalence, too.
- return this->equal_labels (index,
- tc
- ACE_ENV_ARG_PARAMETER);
+ // Check case label.
+ // The label must be equal when determining equivalence, too.
+ return this->equal_label (index,
+ tc
+ ACE_ENV_ARG_PARAMETER);
}
#endif /* TAO_TYPECODE_CASE_CPP */